import { postHashtags } from "@/components/trends/api/post-hashtags"
import { retrieveHashtagsFromGweet } from "@/components/trends/api/retrieve-hashtags-from-gweet"
import { uploadFiles } from "@/lib/uploadthing"

export const postGweet = async ({
    content,
    files,
    authorId,
    replyToGweetId,
    quoteGweetId,
}: {
    content: string
    files: File[]
    authorId: string
    replyToGweetId?: string | null
    quoteGweetId?: string | null
}) => {
    const gweet = {
        content,
        authorId,
        ...(replyToGweetId && { replyToGweetId }),
        ...(quoteGweetId && { quoteGweetId }),
    }

    try {
        let fileprops: { fileUrl: string; fileKey: string }[] = []
        if (files.length > 0) {
            fileprops = await uploadFiles({ files, endpoint: 'mediaUploader' })
        }

        const data = await fetch('/api/gweets', {
            method: 'POST',
            body: JSON.stringify({ gweet, fileprops })
        }).then((result) => result.json())

        const hashtags = retrieveHashtagsFromGweet(content)
        if (hashtags) await postHashtags(hashtags)

        return data
    } catch (error: any) {
        return error.response.data
    }
}