"use client"

import { InfiniteGweets } from "@/components/gweets/components/infinite-gweets"
import { useGweets } from "@/components/gweets/hooks/use-gweets"
import LoadingItem from "@/components/loading-item"
import { TryAgain } from "@/components/try-again"
import { usePathname } from "next/navigation"

export const UserGweets = ({ username, sessionname }: { username: string, sessionname: string }) => {
    const pathValue = usePathname().split("/")[2] || "gweets"

    const {
        data: gweets,
        isLoading,
        isError,
        isSuccess,
        isFetchingNextPage,
        fetchNextPage,
        hasNextPage,
    } = useGweets({
        queryKey: ["gweets", username, pathValue],
        type: "user_" + pathValue,
        id: username,
    })

    if (isLoading) {
        return (
            <LoadingItem />
        )
    }

    if (isError) {
        return (
            <TryAgain />
        )
    }

    if (gweets?.pages[0].gweets.length === 0) {
        if (sessionname === username) {
            return (
                <div className="m-6 flex justify-center">
                    <div className="font-bold">
                        <h1>You haven&apos;t gweeted anything yet.</h1>
                        <p>When you do, it&apos;ll show up here.</p>
                    </div>
                </div>
            )
        } else {
            return (
                <div className="m-6 flex justify-center">
                    <div className="font-bold">
                        <h1><span className="text-sky-500">@{username}</span> hasn&apos;t gweeted anything yet.</h1>
                        <p>When they do, it&apos;ll show up here.</p>
                    </div>
                </div>
            )
        }
    }

    return (
        <InfiniteGweets
            gweets={gweets}
            hasNextPage={hasNextPage}
            fetchNextPage={fetchNextPage}
            isFetchingNextPage={isFetchingNextPage}
            isSuccess={isSuccess}
        />
    )
}